Skip to contents

Records are filtered out of the SoT publication cohort for a variety of reasons. These filters are defined in various functions within sottools and this wrapper applies all the ones needed to define the publicaiton cohort.

Usage

apply_publication_filters(wh_tbl, pub_table)

Arguments

wh_tbl

A lazy_tbl object represenging a warehouse table. This object needs to come from running the function get_wh_tbl() and then create_analysis_variables() on the resulting object.

pub_table

One of "completed", "ongoing", "additions", "removals" to tell the function what data is being looked at and therefore what filters to apply.

Value

A lazy_tbl object with the publication filters applied.

Details

Full documentation of the SoT publication filters can be found WHERE