Create derived variables
create_analysis_variables.RdThere are some variables beyond those in the warehouse views which are required for analysis. This function derives the variables required for further analysis.
Arguments
- wh_tbl
A lazy_tbl object representing a warehouse table. This should be the output of
get_wh_tbl()- pub_table
One of "completed", "ongoing", "additions", "removals" to tell the function what data is being looked at and therefore what variables to derive.