Get a lazy_tbl object from the warehouse
get_wh_tbl.RdOnce a connection to the waiting times warehouse has been established using
wh_connection() this function can be used to create an object which
represents a view from the warehouse.
Examples
con <- wh_connection()
#> Warning: Selecting ‘env’ backend. Secrets are stored in environment variables
#> Error in default_backend()$keyring_unlock(keyring, password): attempt to apply non-function
test <- get_wh_tbl(con, snapshot_live = "SSM", view = "ongoing")
#> Error: object 'con' not found